from .viewsets import UserDeviceViewSet
from rest_framework.routers import DefaultRouter


router = DefaultRouter()
router.register("devices", UserDeviceViewSet, basename="devices")

urlpatterns = router.urls



# Generated by Django 3.2.15 on 2022-10-07 07:01

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Post',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255)),
                ('description', models.TextField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('is_published', models.BooleanField(default=False)),
            ],
        ),
    ]
